Module common

Module common 

Commonly used types.

Structs

ProjectTeam
Contains information about the team related to this DefaultObjectAccessControls

Enums

Entity
An entity is used to represent a user or group of users that often have some kind of permission.
Role
Any type of role we can encounter.
Team
Any type of team we can encounter.